==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/TemplatePermissionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.TemplatePermissionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property actions List of IAM actions to grant or revoke permissions on.
 * @property principal ARN of the principal. See the [ResourcePermission documentation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ResourcePermission.html) for the applicable ARN values.
 */
public data class TemplatePermissionArgs(
    public val actions: Output<List<String>>,
    public val principal: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.TemplatePermissionArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.TemplatePermissionArgs =
        com.pulumi.aws.quicksight.inputs.TemplatePermissionArgs.builder()
            .actions(actions.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .principal(principal.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TemplatePermissionArgs].
 */
@PulumiTagMarker
public class TemplatePermissionArgsBuilder internal constructor() {
    private var actions: Output<List<String>>? = null

    private var principal: Output<String>? = null

    /**
     * @param value List of IAM actions to grant or revoke permissions on.
     */
    @JvmName("ttogbwtoewsklqru")
    public suspend fun actions(`value`: Output<List<String>>) {
        this.actions = value
    }

    @JvmName("vojywkdrcstvbixu")
    public suspend fun actions(vararg values: Output<String>) {
        this.actions = Output.all(values.asList())
    }

    /**
     * @param values List of IAM actions to grant or revoke permissions on.
     */
    @JvmName("owjkcjlkympeeung")
    public suspend fun actions(values: List<Output<String>>) {
        this.actions = Output.all(values)
    }

    /**
     * @param value ARN of the principal. See the [ResourcePermission documentation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ResourcePermission.html) for the applicable ARN values.
     */
    @JvmName("iojighefhhrxbtkk")
    public suspend fun principal(`value`: Output<String>) {
        this.principal = value
    }

    /**
     * @param value List of IAM actions to grant or revoke permissions on.
     */
    @JvmName("ygagcpjdbiaemvmr")
    public suspend fun actions(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param values List of IAM actions to grant or revoke permissions on.
     */
    @JvmName("smsxocamtiyleawb")
    public suspend fun actions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param value ARN of the principal. See the [ResourcePermission documentation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ResourcePermission.html) for the applicable ARN values.
     */
    @JvmName("yqpibmnyowrrxhra")
    public suspend fun principal(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principal = mapped
    }

    internal fun build(): TemplatePermissionArgs = TemplatePermissionArgs(
        actions = actions ?: throw PulumiNullFieldException("actions"),
        principal = principal ?: throw PulumiNullFieldException("principal"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/TemplatePermissionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.TemplatePermissionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property actions List of IAM actions to grant or revoke permissions on.
 * @property principal ARN of the principal. See the [ResourcePermission documentation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ResourcePermission.html) for the applicable ARN values.
 */
public data class TemplatePermissionArgs(
    public val actions: Output<List<String>>,
    public val principal: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.TemplatePermissionArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.TemplatePermissionArgs =
        com.pulumi.aws.quicksight.inputs.TemplatePermissionArgs.builder()
            .actions(actions.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .principal(principal.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TemplatePermissionArgs].
 */
@PulumiTagMarker
public class TemplatePermissionArgsBuilder internal constructor() {
    private var actions: Output<List<String>>? = null

    private var principal: Output<String>? = null

    /**
     * @param value List of IAM actions to grant or revoke permissions on.
     */
    @JvmName("neuugooammfxbicn")
    public suspend fun actions(`value`: Output<List<String>>) {
        this.actions = value
    }

    @JvmName("tgtwhnntmavmkvmn")
    public suspend fun actions(vararg values: Output<String>) {
        this.actions = Output.all(values.asList())
    }

    /**
     * @param values List of IAM actions to grant or revoke permissions on.
     */
    @JvmName("yrsncvfadofcjguq")
    public suspend fun actions(values: List<Output<String>>) {
        this.actions = Output.all(values)
    }

    /**
     * @param value ARN of the principal. See the [ResourcePermission documentation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ResourcePermission.html) for the applicable ARN values.
     */
    @JvmName("lvpsyjwxjbfvhtux")
    public suspend fun principal(`value`: Output<String>) {
        this.principal = value
    }

    /**
     * @param value List of IAM actions to grant or revoke permissions on.
     */
    @JvmName("pcusdeeljahewadd")
    public suspend fun actions(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param values List of IAM actions to grant or revoke permissions on.
     */
    @JvmName("rcthcfeklmdttuie")
    public suspend fun actions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param value ARN of the principal. See the [ResourcePermission documentation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ResourcePermission.html) for the applicable ARN values.
     */
    @JvmName("rgjtwfbohpervloo")
    public suspend fun principal(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principal = mapped
    }

    internal fun build(): TemplatePermissionArgs = TemplatePermissionArgs(
        actions = actions ?: throw PulumiNullFieldException("actions"),
        principal = principal ?: throw PulumiNullFieldException("principal"),
    )
}
